(this.webpackJsonpstreamlit_component_template=this.webpackJsonpstreamlit_component_template||[]).push([[0],{21:function(e,t,a){e.exports=a(31)},31:function(e,t,a){"use strict";a.r(t);var n,r,i=a(1),s=a.n(i),o=a(19),c=a.n(o),l=a(17),d=a(11),p=a(13),m=a(9),u=a(20),g=a.n(u),h=Object(d.b)((function(e){Object(i.useEffect)((function(){return d.a.setFrameHeight()}));var t,a=e.args,o=a.isUser,c=a.avatarStyle,u=a.seed,h=a.animateFrom,f=a.value,b=a.useTypewriter;t=c.startsWith("https")||c.startsWith("data:image")?c:"https://avatars.dicebear.com/api/".concat(c,"/").concat(u,".svg");var x=e.theme;if(!x)return s.a.createElement("div",null,"Theme is undefined, please check streamlit version.");var v=p.a.img({border:"1px solid transparent",height:"3rem",width:"3rem",margin:0}),E=p.a.div({display:"inline-block",background:x.secondaryBackgroundColor,border:"1px solid transparent",borderRadius:"10px",padding:"10px 14px",margin:"5px 20px",maxWidth:"70%",whiteSpace:"pre-wrap"}),y=p.a.div({display:"flex",fontFamily:"".concat(x.font,", 'Segoe UI', 'Roboto', sans-serif"),height:"auto",margin:0,width:"100%"},(function(e){return e.isUser?Object(m.a)(n||(n=Object(l.a)(["\n        flex-direction: row-reverse;\n        & > div {\n          text-align: right;\n        }\n        padding-right: 5px;\n      "]))):Object(m.a)(r||(r=Object(l.a)([""])))}));return!o&&b?s.a.createElement(y,{isUser:o},s.a.createElement(v,{src:t,alt:"profile",draggable:"false"}),s.a.createElement(E,null,s.a.createElement(g.a,{options:{delay:10,cursor:"\u258e",onCreateTextNode:function(e){return d.a.setFrameHeight(),document.createTextNode(e)}},onInit:function(e){e.pasteString(h,null).typeString(f.split(h).join("")).callFunction((function(t){setTimeout((function(){return t.elements.cursor.setAttribute("hidden","hidden")}),3500),e.stop()})).start()}}))):s.a.createElement(y,{isUser:o},s.a.createElement(v,{src:t,alt:"profile",draggable:"false"}),s.a.createElement(E,null,f))}));c.a.render(s.a.createElement(s.a.StrictMode,null,s.a.createElement(h,null)),document.getElementById("root"))}},[[21,1,2]]]);
//# sourceMappingURL=main.034a66d0.chunk.js.map